==> quanyi-center-api-1.1.70-20240927.081631-14-sources.jar: cn/com/duiba/quanyi/center/api/dto/qy/statement/StatementDemandOfflineGoodsDto.java <==
package cn.com.duiba.quanyi.center.api.dto.qy.statement;

import java.io.Serializable;
import java.time.LocalDate;
import java.util.Date;
import lombok.Data;

/**
 * 结算单线下商品记录表
 * @author mybatis generator 
 * @date 2024-09-27
 */
@Data
public class StatementDemandOfflineGoodsDto implements Serializable {
     
    private static final long serialVersionUID = 17274072851219893L;

    /**
     * 主键
     */
    private Long id;

    /**
     * 创建时间
     */
    private Date gmtCreate;

    /**
     * 修改时间
     */
    private Date gmtModified;

    /**
     * 结算单ID
     */
    private Long statementId;

    /**
     * 需求ID
     */
    private Long demandId;

    /**
     * 合同ID
     */
    private Long contractId;

    /**
     * 商品ID
     */
    private Integer goodsId;

    /**
     * 商品类别
     */
    private String goodType;

    /**
     * 商品名称
     */
    private String goodsName;

    /**
     * 结算价
     */
    private Long settlementRate;

    /**
     * 核销净额
     */
    private Long netVerifiedAmount;

    /**
     * 结算金额
     */
    private Long settlementAmount;

    /**
     * 结算开始日期
     */
    private LocalDate settlementStartDate;

    /**
     * 结算结束日期
     */
    private LocalDate settlementEndDate;

    /**
     * 创建人姓名
     */
    private String creatorName;

    /**
     * 创建人ID
     */
    private Long creatorId;

    /**
     * 打款明细ID
     */
    private Long paymentDetailId;

    /**
     * 打款金额
     */
    private Long paymentAmount;

    /**
     * 打款日期
     */
    private LocalDate paymentDate;
}

==> quanyi-center-api-1.1.70-20240927.160053-20-sources.jar: cn/com/duiba/quanyi/center/api/dto/qy/statement/StatementDemandOfflineGoodsDto.java <==
package cn.com.duiba.quanyi.center.api.dto.qy.statement;

import java.io.Serializable;
import java.time.LocalDate;
import java.util.Date;
import lombok.Data;

/**
 * 结算单线下商品记录表
 * @author mybatis generator 
 * @date 2024-09-27
 */
@Data
public class StatementDemandOfflineGoodsDto implements Serializable {
     
    private static final long serialVersionUID = 17274072851219893L;

    /**
     * 主键
     */
    private Long id;

    /**
     * 创建时间
     */
    private Date gmtCreate;

    /**
     * 修改时间
     */
    private Date gmtModified;

    /**
     * 结算单ID
     */
    private Long statementId;

    /**
     * 需求ID
     */
    private Long demandId;

    /**
     * 合同ID
     */
    private Long contractId;

    /**
     * 商品ID
     */
    private Long goodsId;

    /**
     * 商品类别
     */
    private String goodsType;

    /**
     * 商品名称
     */
    private String goodsName;

    /**
     * 结算价
     */
    private Long settlementRate;

    /**
     * 核销净额
     */
    private Long netVerifiedAmount;

    /**
     * 结算金额
     */
    private Long settlementAmount;

    /**
     * 结算开始日期
     */
    private LocalDate settlementStartDate;

    /**
     * 结算结束日期
     */
    private LocalDate settlementEndDate;

    /**
     * 创建人姓名
     */
    private String creatorName;

    /**
     * 创建人ID
     */
    private Long creatorId;

    /**
     * 打款明细ID
     */
    private Long paymentDetailId;

    /**
     * 打款金额
     */
    private Long paymentAmount;

    /**
     * 打款日期
     */
    private LocalDate paymentDate;
}
